@@ -23,6 +23,9 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 数据库连接失败，请检查参数是否填写正确。
+FAILEDOPERATION_DATASOURCECONNECTIONFAILED = 'FailedOperation.DataSourceConnectionFailed'
+
 # 重复的作业名。
 FAILEDOPERATION_DUPLICATEDJOBNAME = 'FailedOperation.DuplicatedJobName'
 
@@ -80,12 +83,18 @@ INTERNALERROR_STSNEWCLIENT = 'InternalError.StsNewClient'
 # 系统错误。
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
+# 参数错误。
+INVALIDPARAMETER = 'InvalidParameter'
+
 # AppId资源不匹配。
 INVALIDPARAMETER_APPIDRESOURCENOTMATCH = 'InvalidParameter.AppIdResourceNotMatch'
 
 # 非法的 MaxParallelism 参数。
 INVALIDPARAMETER_ILLEGALMAXPARALLELISM = 'InvalidParameter.IllegalMaxParallelism'
 
+# 非法的搜索字符串。
+INVALIDPARAMETER_ILLEGALSEARCHKEYWORD = 'InvalidParameter.IllegalSearchKeyword'
+
 # appid错误。
 INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'
 
@@ -128,9 +137,15 @@ INVALIDPARAMETERVALUE_CLUSTERIDS = 'InvalidParameterValue.ClusterIds'
 # CU内存规格不匹配。
 INVALIDPARAMETERVALUE_CUMEM = 'InvalidParameterValue.CuMem'
 
+# 无效限制错误。
+INVALIDPARAMETERVALUE_INVALIDLIMIT = 'InvalidParameterValue.InvalidLimit'
+
 # 无效启动模式。
 INVALIDPARAMETERVALUE_INVALIDSTARTMODE = 'InvalidParameterValue.InvalidStartMode'
 
+# 无效时间错误。
+INVALIDPARAMETERVALUE_INVALIDTIME = 'InvalidParameterValue.InvalidTime'
+
 # 作业id的参数无效。
 INVALIDPARAMETERVALUE_JOBIDVALUEERROR = 'InvalidParameterValue.JobIdValueError'
 
@@ -203,6 +218,9 @@ RESOURCENOTFOUND_JOBCONFIG = 'ResourceNotFound.JobConfig'
 # 找不到作业。
 RESOURCENOTFOUND_JOBID = 'ResourceNotFound.JobId'
 
+# 找不到日志。
+RESOURCENOTFOUND_LOGTOPIC = 'ResourceNotFound.LogTopic'
+
 # 程序包不存在。
 RESOURCENOTFOUND_RESOURCE = 'ResourceNotFound.Resource'
 
@@ -257,6 +275,9 @@ UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
+# Cls Sql未启用。
+UNSUPPORTEDOPERATION_CLSSQLNOTENABLED = 'UnsupportedOperation.ClsSqlNotEnabled'
+
 # Checkpoint 时间间隔，错误。
 UNSUPPORTEDOPERATION_INVALIDCHECKPOINTINTERVALERROR = 'UnsupportedOperation.InvalidCheckpointIntervalError'
 
