@@ -371,6 +371,29 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAccessHistogram(self, request):
+        """本接口用于访问日志柱状趋势图
+
+        :param request: Request instance for DescribeAccessHistogram.
+        :type request: :class:`tencentcloud.waf.v20180125.models.DescribeAccessHistogramRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.DescribeAccessHistogramResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAccessHistogram", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAccessHistogramResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAccessIndex(self, request):
         """本接口用于获取访问日志索引配置信息
 
@@ -879,6 +902,29 @@ class WafClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetAttackHistogram(self, request):
+        """生成攻击日志的产生时间柱状图
+
+        :param request: Request instance for GetAttackHistogram.
+        :type request: :class:`tencentcloud.waf.v20180125.models.GetAttackHistogramRequest`
+        :rtype: :class:`tencentcloud.waf.v20180125.models.GetAttackHistogramResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetAttackHistogram", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetAttackHistogramResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyAccessPeriod(self, request):
         """本接口用于修改访问日志保存期限及大字段是否存储
 
